"""
Python logger for the telnet server.
"""
import logging

logger = logging.getLogger(__package__)

__all__ = [
    "logger",
]
